==> create-fly-1.21.8-6.0.8-2-sources.jar: com/zurrtum/create/infrastructure/packet/s2c/TrainHUDControlUpdatePacket.java <==
package com.zurrtum.create.infrastructure.packet.s2c;

import com.zurrtum.create.AllClientHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecBuilders;
import com.zurrtum.create.content.trains.entity.Train;
import org.apache.logging.log4j.util.TriConsumer;

import java.util.UUID;
import net.minecraft.class_4844;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record TrainHUDControlUpdatePacket(UUID trainId, Double throttle, double speed, int fuelTicks) implements S2CPacket {
    public static final class_9139<class_9129, TrainHUDControlUpdatePacket> CODEC = class_9139.method_56905(
        class_4844.field_48453,
        TrainHUDControlUpdatePacket::trainId,
        CatnipStreamCodecBuilders.nullable(class_9135.field_48553),
        TrainHUDControlUpdatePacket::throttle,
        class_9135.field_48553,
        TrainHUDControlUpdatePacket::speed,
        class_9135.field_48550,
        TrainHUDControlUpdatePacket::fuelTicks,
        TrainHUDControlUpdatePacket::new
    );

    public TrainHUDControlUpdatePacket(Train train) {
        this(train.id, train.throttle, nonStalledSpeed(train), train.fuelTicks);
    }

    private static double nonStalledSpeed(Train train) {
        return train.speedBeforeStall == null ? train.speed : train.speedBeforeStall;
    }

    @Override
    public class_9145<TrainHUDControlUpdatePacket> method_65080() {
        return AllPackets.S_TRAIN_HUD;
    }

    @Override
    public <T> TriConsumer<AllClientHandle<T>, T, TrainHUDControlUpdatePacket> callback() {
        return AllClientHandle::onTrainHUDControlUpdate;
    }
}

==> create-fly-1.21.10-6.0.8-5-sources.jar: com/zurrtum/create/infrastructure/packet/s2c/TrainHUDControlUpdatePacket.java <==
package com.zurrtum.create.infrastructure.packet.s2c;

import com.zurrtum.create.AllClientHandle;
import com.zurrtum.create.AllPackets;
import com.zurrtum.create.catnip.codecs.stream.CatnipStreamCodecBuilders;
import com.zurrtum.create.content.trains.entity.Train;
import java.util.UUID;
import net.minecraft.class_2596;
import net.minecraft.class_2602;
import net.minecraft.class_4844;
import net.minecraft.class_9129;
import net.minecraft.class_9135;
import net.minecraft.class_9139;
import net.minecraft.class_9145;

public record TrainHUDControlUpdatePacket(UUID trainId, Double throttle, double speed, int fuelTicks) implements class_2596<class_2602> {
    public static final class_9139<class_9129, TrainHUDControlUpdatePacket> CODEC = class_9139.method_56905(
        class_4844.field_48453,
        TrainHUDControlUpdatePacket::trainId,
        CatnipStreamCodecBuilders.nullable(class_9135.field_48553),
        TrainHUDControlUpdatePacket::throttle,
        class_9135.field_48553,
        TrainHUDControlUpdatePacket::speed,
        class_9135.field_48550,
        TrainHUDControlUpdatePacket::fuelTicks,
        TrainHUDControlUpdatePacket::new
    );

    public TrainHUDControlUpdatePacket(Train train) {
        this(train.id, train.throttle, nonStalledSpeed(train), train.fuelTicks);
    }

    private static double nonStalledSpeed(Train train) {
        return train.speedBeforeStall == null ? train.speed : train.speedBeforeStall;
    }

    @Override
    public void apply(class_2602 listener) {
        AllClientHandle.INSTANCE.onTrainHUDControlUpdate(this);
    }

    @Override
    public class_9145<TrainHUDControlUpdatePacket> method_65080() {
        return AllPackets.S_TRAIN_HUD;
    }
}
